@@ -24,7 +24,7 @@ def respond(result, message=None, success=True):
     print(response_json)
 
 
-def run(runner, debug=False, text=False):
+def run(runner, debug=False, text=False, exit_code_on_error=1):
     try:
         data = runner()
         if text:
@@ -34,7 +34,7 @@ def run(runner, debug=False, text=False):
     except Exception, e:
         log.exception('got an exception')
         respond(e, str(e), success=False)
-        exit(1)
+        exit(exit_code_on_error)
 
 
 def execute(obj, args):
